@@ -1,10 +1,8 @@
 //  Copyright John R. Bandela 2001. 
 
-// Permission to copy, use, modify, sell and distribute this software
-// is granted provided this copyright notice appears in all
-// copies. This software is provided "as is" without express or
-// implied warranty, and with no claim as to its suitability for any
-// purpose.
+// Distributed under the Boost Software License, Version 1.0. (See
+// accompanying file LICENSE_1_0.txt or copy at
+// http://www.boost.org/LICENSE_1_0.txt)
 
 // See http://www.boost.org/libs/tokenizer for documenation
 
@@ -21,5 +19,6 @@ int main(){
    for(tokenizer<char_delimiters_separator<char> >::iterator beg=tok.begin(); beg!=tok.end();++beg){
        cout << *beg << "\n";
    }
+   return 0;
 }
 
